// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `Metadata terms for vocabulary description` vocabulary
//!
//! This module requires `ns-dcam` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|Metadata terms for vocabulary description|
//! |**Prefix**|dcam|
//! |**Namespace base IRI**|<http://purl.org/dc/dcam/>|
//! |**Description**||
//! |**Is defined by**|<http://purl.org/dc/dcam/>|
//!

use crate::namespace;

namespace!(
    "http://purl.org/dc/dcam/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Vocabulary Encoding Scheme`: An enumerated set of resources.
    VocabularyEncodingScheme, "VocabularyEncodingScheme",
    /// `Domain Includes`: A suggested class for subjects of this property.
    domainIncludes, "domainIncludes",
    /// `Member Of`: A relationship between a resource and a vocabulary encoding scheme which indicates that the resource is a member of a set.
    memberOf, "memberOf",
    /// `Range Includes`: A suggested class for values of this property.
    rangeIncludes, "rangeIncludes"
);
